==> 4.1.tar.gz: retropie-setup/scriptmodules/libretrocores/lr-mess.sh <==
#!/usr/bin/env bash

# This file is part of The RetroPie Project
#
# The RetroPie Project is the legal property of its developers, whose names are
# too numerous to list here. Please refer to the COPYRIGHT.md file distributed with this source.
#
# See the LICENSE.md file at the top-level directory of this distribution and
# at https://raw.githubusercontent.com/RetroPie/RetroPie-Setup/master/LICENSE.md
#

rp_module_id="lr-mess"
rp_module_desc="MESS emulator - MESS Port for libretro"
rp_module_help="see wiki for detailed explanation"
rp_module_section="exp"

function sources_lr-mess() {
    gitPullOrClone "$md_build" https://github.com/libretro/MAME.git
}

function build_lr-mess() {
    make -f Makefile.libretro clean
    make -f Makefile.libretro SUBTARGET=mess
    md_ret_require="$md_build/mess_libretro.so"
}

function install_lr-mess() {
    md_ret_files=(
        'mess_libretro.so'
    )
}

function configure_lr-mess() {
    mkRomDir "nes"
    mkRomDir "gameboy"
    mkRomDir "coleco"
    mkRomDir "arcadia"
    mkRomDir "crvision"
    ensureSystemretroconfig "nes"
    ensureSystemretroconfig "gameboy"
    ensureSystemretroconfig "coleco"
    ensureSystemretroconfig "arcadia"
    ensureSystemretroconfig "crvision"

    setRetroArchCoreOption "mame_softlists_enable" "enabled"
    setRetroArchCoreOption "mame_softlists_auto_media" "enabled"
    setRetroArchCoreOption "mame_boot_from_cli" "enabled"

    mkdir "$biosdir/mame"
    cp -rv "$md_build/hash" "$biosdir/mame/"
    chown -R $user:$user "$biosdir/mame"
    addSystem 0 "$md_id" "nes" "$md_inst/mess_libretro.so"
    addSystem 0 "$md_id" "gameboy" "$md_inst/mess_libretro.so"
    addSystem 0 "$md_id" "coleco" "$md_inst/mess_libretro.so"
    addSystem 0 "$md_id" "arcadia" "$md_inst/mess_libretro.so"
    addSystem 0 "$md_id" "crvision" "$md_inst/mess_libretro.so"
}

==> 4.3.tar.gz: retropie-setup/scriptmodules/libretrocores/lr-mess.sh <==
#!/usr/bin/env bash

# This file is part of The RetroPie Project
#
# The RetroPie Project is the legal property of its developers, whose names are
# too numerous to list here. Please refer to the COPYRIGHT.md file distributed with this source.
#
# See the LICENSE.md file at the top-level directory of this distribution and
# at https://raw.githubusercontent.com/RetroPie/RetroPie-Setup/master/LICENSE.md
#

rp_module_id="lr-mess"
rp_module_desc="MESS emulator - MESS Port for libretro"
rp_module_help="see wiki for detailed explanation"
rp_module_licence="GPL2 https://raw.githubusercontent.com/libretro/mame/master/LICENSE.md"
rp_module_section="exp"

function depends_lr-mess() {
    depends_lr-mame
}

function sources_lr-mess() {
    gitPullOrClone "$md_build" https://github.com/libretro/mame.git
}

function build_lr-mess() {
    rpSwap on 1200
    local params=($(_get_params_lr-mame) SUBTARGET=mess)
    make clean
    make "${params[@]}"
    rpSwap off
    md_ret_require="$md_build/mess_libretro.so"
}

function install_lr-mess() {
    md_ret_files=(
        'LICENSE.md'
        'mess_libretro.so'
        'README.md'
    )
}

function configure_lr-mess() {
    local module="$1"
    [[ -z "$module" ]] && module="mess_libretro.so"

    local system
    for system in nes gameboy coleco arcadia crvision; do
        mkRomDir "$system"
        ensureSystemretroconfig "$system"
        addEmulator 0 "$md_id" "$system" "$md_inst/$module"
        addSystem "$system"
    done

    setRetroArchCoreOption "mame_softlists_enable" "enabled"
    setRetroArchCoreOption "mame_softlists_auto_media" "enabled"
    setRetroArchCoreOption "mame_boot_from_cli" "enabled"

    mkdir "$biosdir/mame"
    cp -rv "$md_build/hash" "$biosdir/mame/"
    chown -R $user:$user "$biosdir/mame"
}
